==> org.eclipse.m2e.pde.ui.source_1.18.2.20211002-1029.jar: org/eclipse/m2e/pde/ui/editor/Messages.java <==
package org.eclipse.m2e.pde.ui.editor;

import org.eclipse.osgi.util.NLS;

public class Messages extends NLS {
	private static final String BUNDLE_NAME = "org.eclipse.m2e.pde.ui.editor.messages"; //$NON-NLS-1$
	public static String MavenArtifactInstructionsWizard_0;
	public static String MavenArtifactInstructionsWizard_1;
	public static String MavenArtifactInstructionsWizard_2;
	public static String MavenArtifactInstructionsWizard_3;
	public static String MavenArtifactInstructionsWizard_4;
	public static String MavenArtifactInstructionsWizard_6;
	public static String MavenTargetLocationWizard_0;
	public static String MavenTargetLocationWizard_1;
	public static String MavenTargetLocationWizard_2;
	public static String MavenTargetDependencyEditor_1;
	public static String MavenTargetDependencyEditor_2;
	public static String MavenTargetDependencyEditor_3;
	public static String MavenTargetDependencyEditor_4;
	public static String MavenTargetDependencyEditor_5;
	public static String MavenTargetDependencyEditor_6;
	public static String MavenTargetLocationWizard_8;
	public static String MavenTargetLocationWizard_9;
	public static String MavenTargetLocationWizard_10;
	public static String MavenTargetLocationWizard_11;
	public static String MavenTargetLocationWizard_12;
	public static String MavenTargetRepositoryEditor_1;
	public static String ClipboardParser_1;
	public static String MavenTargetLocationWizard_15;
	public static String MavenTargetLocationWizard_20;
	public static String MavenTargetLocationWizard_21;
	public static String MavenTargetLocationWizard_23;
	public static String MavenTargetLocationLabelProvider_1;
	public static String MavenTargetLocationLabelProvider_2;
	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
	}

	private Messages() {
	}
}

==> org.eclipse.m2e.pde.ui.source_1.20.0.20220206-0542.jar: org/eclipse/m2e/pde/ui/editor/Messages.java <==
package org.eclipse.m2e.pde.ui.editor;

import org.eclipse.osgi.util.NLS;

public class Messages extends NLS {
	private static final String BUNDLE_NAME = "org.eclipse.m2e.pde.ui.editor.messages"; //$NON-NLS-1$
	public static String NewFeatureWizard_PlugPage_desc;
	public static String NewFeatureWizard_PlugPage_title;
	public static String MavenArtifactInstructionsWizard_0;
	public static String MavenArtifactInstructionsWizard_1;
	public static String MavenArtifactInstructionsWizard_2;
	public static String MavenArtifactInstructionsWizard_3;
	public static String MavenArtifactInstructionsWizard_4;
	public static String MavenArtifactInstructionsWizard_6;
	public static String MavenTargetLocationWizard_0;
	public static String MavenTargetLocationWizard_1;
	public static String MavenTargetLocationWizard_2;
	public static String MavenTargetDependencyEditor_1;
	public static String MavenTargetDependencyEditor_2;
	public static String MavenTargetDependencyEditor_3;
	public static String MavenTargetDependencyEditor_4;
	public static String MavenTargetDependencyEditor_5;
	public static String MavenTargetDependencyEditor_6;
	public static String MavenTargetLocationWizard_8;
	public static String MavenTargetLocationWizard_9;
	public static String MavenTargetLocationWizard_10;
	public static String MavenTargetLocationWizard_11;
	public static String MavenTargetLocationWizard_12;
	public static String MavenTargetLocationWizard_13;
	public static String MavenTargetLocationWizard_14;
	public static String MavenTargetLocationWizard_15;
	public static String MavenTargetLocationWizard_16;
	public static String MavenTargetLocationWizard_17;
	public static String MavenTargetRepositoryEditor_1;
	public static String ClipboardParser_1;
	public static String MavenTargetLocationWizard_20;
	public static String MavenTargetLocationWizard_21;
	public static String MavenTargetLocationWizard_23;
	public static String MavenTargetLocationLabelProvider_1;
	public static String MavenTargetLocationLabelProvider_2;
	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
	}

	private Messages() {
	}
}
